IsolateImage class
Image Entity Use in package
- Available extensions
Constructors
- IsolateImage({Uint8List? data, String? path})
- IsolateImage.data(Uint8List data)
-
factory
- IsolateImage.path(String path)
-
factory
Properties
- data → Uint8List?
-
no setter
- filePath → String?
-
final
- fromType → ImageFromType
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compress(
{int? maxSize, ImageResolution? maxResolution, ImageFormat? format}) → Future< Uint8List?> -
Available on IsolateImage, provided by the CompressOnIsolateImage extension
Compress image. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resizeWithResolution(
ImageResolution resolution) → Image? -
Available on IsolateImage, provided by the ResizeOnIsolateImage extension
Resize image with resolution -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited